@@ -1,5 +1,6 @@
 package QuadPres;
-$QuadPres::VERSION = '0.28.1';
+$QuadPres::VERSION = '0.28.2';
+use 5.016;
 use strict;
 use warnings;
 
@@ -810,7 +811,7 @@ sub traverse_tree
             {
                 $traverse_helper->(
                     [ @$path_ref, $sub_branch->{'url'} ],
-                    [ @$coords,   $new_coord ], $sub_branch,
+                    [ @$coords, $new_coord ], $sub_branch,
                 );
             }
             continue
@@ -863,21 +864,13 @@ __END__
 
 =head1 NAME
 
-QuadPres
-
-=head1 VERSION
-
-version 0.28.1
-
-=head1 NAME
-
 QuadPres - a presentation / slides manager.
 
 =head1 VERSION
 
-version 0.28.1
+version 0.28.2
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -898,14 +891,6 @@ L<https://metacpan.org/release/QuadPres>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/QuadPres>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -914,22 +899,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=QuadPres>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/QuadPres>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/QuadPres>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
