@@ -1,5 +1,6 @@
 package QuadPres::Config;
-$QuadPres::Config::VERSION = '0.28.1';
+$QuadPres::Config::VERSION = '0.28.2';
+use 5.016;
 use strict;
 use warnings;
 
@@ -149,15 +150,11 @@ __END__
 
 =encoding UTF-8
 
-=head1 NAME
-
-QuadPres::Config
-
 =head1 VERSION
 
-version 0.28.1
+version 0.28.2
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -178,14 +175,6 @@ L<https://metacpan.org/release/QuadPres>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/QuadPres>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -194,22 +183,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=QuadPres>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/QuadPres>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/QuadPres>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
